@@ -74,10 +74,13 @@ void FlatpakNotifier::recheckSystemUpdateNeeded()
 
 void FlatpakNotifier::onFetchUpdatesFinished(Installation *installation, bool hasUpdates)
 {
-    const bool changed = this->hasUpdates() != hasUpdates;
+    if (installation->m_hasUpdates == hasUpdates) {
+        return;
+    }
+    bool hadUpdates = this->hasUpdates();
     installation->m_hasUpdates = hasUpdates;
 
-    if (changed) {
+    if (hadUpdates != this->hasUpdates()) {
         Q_EMIT foundUpdates();
     }
 }
@@ -140,7 +143,7 @@ bool FlatpakNotifier::setupFlatpakInstallations(GError **error)
         return false;
     if (!m_user.ensureInitialized(
             [this, error] {
-                return flatpak_installation_new_system(m_cancellable, error);
+                return flatpak_installation_new_user(m_cancellable, error);
             },
             m_cancellable,
             error))
