@@ -36,7 +36,7 @@
 #include "utils.h"
 #include <resources/StandardBackendUpdater.h>
 
-static const int PAGE_SIZE = 100;
+static const int ENGINE_PAGE_SIZE = 100;
 
 class KNSBackendFactory : public AbstractResourcesBackendFactory
 {
@@ -67,7 +67,9 @@ public:
     }
 };
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 Q_DECLARE_METATYPE(KNSCore::EntryInternal)
+#endif
 
 KNSBackend::KNSBackend(QObject *parent, const QString &iconName, const QString &knsrc)
     : AbstractResourcesBackend(parent)
@@ -92,7 +94,10 @@ KNSBackend::KNSBackend(QObject *parent, const QString &iconName, const QString &
 
     const KConfigGroup group = conf.group("KNewStuff3");
     m_extends = group.readEntry("Extends", QStringList());
+
+#if KNEWSTUFFCORE_VERSION < QT_VERSION_CHECK(5, 92, 0)
     m_reviews->setProviderUrl(QUrl(group.readEntry("ProvidersUrl", QString())));
+#endif
 
     setFetching(true);
 
@@ -160,7 +165,7 @@ KNSBackend::KNSBackend(QObject *parent, const QString &iconName, const QString &
             }
         }
     });
-    m_engine->setPageSize(PAGE_SIZE);
+    m_engine->setPageSize(ENGINE_PAGE_SIZE);
     m_engine->init(m_name);
 
     if (m_hasApplications) {
@@ -378,7 +383,7 @@ void KNSBackend::receivedEntries(const KNSCore::EntryInternal::List &entries)
     }
 
     setResponsePending(false);
-    if (m_onePage || resources.count() < PAGE_SIZE) {
+    if (m_onePage || resources.count() < ENGINE_PAGE_SIZE) {
         Q_EMIT searchFinished();
     }
 }
