@@ -38,6 +38,34 @@ Q_SIGNALS:
     void fetchMore();
 };
 
+class DISCOVERCOMMON_EXPORT HelpfulError : public QObject
+{
+    Q_OBJECT
+    Q_PROPERTY(QString iconName MEMBER m_iconName CONSTANT)
+    Q_PROPERTY(QString errorMessage MEMBER m_errorMessage CONSTANT)
+    Q_PROPERTY(QVariantList actions MEMBER m_actions CONSTANT)
+public:
+    HelpfulError(const QString &iconName, const QString &error, const QVariantList &actions = {})
+        : m_iconName(iconName)
+        , m_errorMessage(error)
+        , m_actions(actions)
+    {
+    }
+
+private:
+    QString m_iconName;
+    QString m_errorMessage;
+    QVariantList m_actions;
+};
+
+// Keep in sync with Kirigami's enums.h
+enum InlineMessageType {
+    Information = 0,
+    Positive,
+    Warning,
+    Error,
+};
+
 /**
  * \class AbstractResourcesBackend  AbstractResourcesBackend.h "AbstractResourcesBackend.h"
  *
@@ -200,6 +228,11 @@ public Q_SLOTS:
      */
     virtual void checkForUpdates() = 0;
 
+    /**
+     * Provides a guess why a search might not have offered satisfactory results
+     */
+    Q_SCRIPTABLE virtual HelpfulError *explainDysfunction() const;
+
 Q_SIGNALS:
     /**
      * Notify of a change in the backend
@@ -223,6 +256,7 @@ Q_SIGNALS:
     void resourceRemoved(AbstractResource *resource);
 
     void passiveMessage(const QString &message);
+    void inlineMessage(InlineMessageType type, const QString &iconName, const QString &message);
     void fetchingUpdatesProgressChanged();
 
 private:
