@@ -26,8 +26,9 @@ int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
     app.setOrganizationDomain(QStringLiteral("kde.org"));
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-
+#endif
     KCrash::setFlags(KCrash::AutoRestart);
 
     NotifierItem notifier;
@@ -39,7 +40,7 @@ int main(int argc, char **argv)
                          version,
                          i18n("System update status notifier"),
                          KAboutLicense::GPL,
-                         i18n("© 2010-2021 Plasma Development Team"));
+                         i18n("© 2010-2022 Plasma Development Team"));
         about.addAuthor(QStringLiteral("Aleix Pol Gonzalez"), {}, QStringLiteral("aleixpol@kde.org"));
         about.setProductName("discover/discover");
         about.setProgramLogo(app.windowIcon());
